==> apache-cassandra-1.2.3-src.tar.gz: apache-cassandra-1.2.3-src/src/java/org/apache/cassandra/exceptions/AlreadyExistsException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.cassandra.exceptions;

public class AlreadyExistsException extends ConfigurationException
{
    public final String ksName;
    public final String cfName;

    private AlreadyExistsException(String ksName, String cfName, String msg)
    {
        super(ExceptionCode.ALREADY_EXISTS, msg);
        this.ksName = ksName;
        this.cfName = cfName;
    }

    public AlreadyExistsException(String ksName, String cfName)
    {
        this(ksName, cfName, String.format("Cannot add already existing column family \"%s\" to keyspace \"%s\"", ksName, cfName));
    }

    public AlreadyExistsException(String ksName)
    {
        this(ksName, "", String.format("Cannot add existing keyspace \"%s\"", ksName));
    }

}

==> apache-cassandra-2.1.22-src.tar.gz: apache-cassandra-2.1.22-src/src/java/org/apache/cassandra/exceptions/AlreadyExistsException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.cassandra.exceptions;

public class AlreadyExistsException extends ConfigurationException
{
    public final String ksName;
    public final String cfName;

    private AlreadyExistsException(String ksName, String cfName, String msg)
    {
        super(ExceptionCode.ALREADY_EXISTS, msg);
        this.ksName = ksName;
        this.cfName = cfName;
    }

    public AlreadyExistsException(String ksName, String cfName)
    {
        this(ksName, cfName, String.format("Cannot add already existing column family \"%s\" to keyspace \"%s\"", cfName, ksName));
    }

    public AlreadyExistsException(String ksName)
    {
        this(ksName, "", String.format("Cannot add existing keyspace \"%s\"", ksName));
    }

}
